#
# spec file for package audex
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           audex
Version:        25.04.1
Release:        1.1
Summary:        Tool for ripping compact discs
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/audex
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  cdparanoia-devel
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KCddb6) >= 5.1
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
Recommends:     faac
Recommends:     flac
Recommends:     lame
Recommends:     python-eyeD3
Recommends:     vorbis-tools

%description
Audex is an audio grabber tool for CD-ROM drives.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name}

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.audex.desktop
%{_kf6_appstreamdir}/org.kde.audex.appdata.xml
%{_kf6_bindir}/audex
%{_kf6_iconsdir}/hicolor/*/apps/org.kde.audex.svg
%{_kf6_sharedir}/audex/
%dir %{_kf6_sharedir}/solid
%dir %{_kf6_sharedir}/solid/actions
%{_kf6_sharedir}/solid/actions/audex-rip-audiocd.desktop

%files lang -f %{name}.lang

%changelog
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- No code change since 25.04.0
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- No code change since 24.12.3
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Fix appdata to align with appstream spec
  * Fix quote handling for metadata
  * Use string literals in encoder assistant class
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * org.kde.audex.appdata.xml : Fix minor typo in description
  * Improve English in appdata
  * Update logo
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Update logo
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
  * Port to KF6/Qt6
* Sun Jan 10 2021 christophe@krop.fr
- Use a snapshot tracking git for audex. The current package still
  uses KDE4/Qt4 which is long dead.
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Mon Nov 17 2014 ecsos@opensuse.org
- update to 0.79
  * This is only a bugfix release.
* Sat Feb 22 2014 ecsos@opensuse.org
- update to 0.78
  * Fixed google cover search
  * Embed cover in FLAC files
  * Minor bugfixes, code modifications and typo fixes...
* Sat Feb 16 2013 asterios.dramis@gmail.com
- Update to 0.77b1:
  * Removed store discid file feature as this is useless considering info file
    feature
  * Integrated new playlist module (relative filenames in playlists and
    playlist merging)
  * Minor bugfixes, code modifications and typo fixes...
  From 0.76b2:
  * Some minor code fixes
  * Cue sheet writer now follows the file format specs (not using OGG and FLAC
    anymore)
  * Some minor bugfixes...
- Removed require_cmake_2.6.4.patch (not needed anymore).
- Removed install_translations.diff (fixed upstream).
* Mon Jan 21 2013 ctrippe@opensuse.org
- Update to 0.76b1
  * Fix google cover fetcher (bnc#799499)
  * Fix compile issues with GCC 4.7 (drop audex-gcc47.patch)
- Added patch to install translations
* Mon Apr 30 2012 idonmez@suse.com
- Fix compilation with gcc 4.7
* Tue Feb 15 2011 asterios.dramis@gmail.com
- Updated to 0.74b1
  * New feature: Simple cue sheet support (but does not detect pregaps yet)
  * New feature: Single file rip
  * New feature: Adds MD5 to hashlist options
  * Fixes some issues with cover browser
  * Uses external image viewer to show cover
  * Bugfix in Ogg Vorbis settings widget
  * Ogg Vorbis setting widget now allows to set fractional quality values
  * Bugfix in commandline for FAAC
  * 2 digits track number option for filenames
  * New parameters for file name scheme variables: left (see
    kde.maniatek.com/audex for full documentation)
  * New helptext for scheme wizard dialogs
  * Pattern of playlists, hashlists and cover files now need a $suffix variable
  * Some more small bugfixes...
- Spec file updates
  * Changed License: to GPLv3+.
  * Minor fixes.
  * Fix Categories: entry of audex.desktop file.
* Sun Jan  9 2011 asterios.dramis@gmail.com
- Updated to 0.73b1
  * New feature: Use eyeD3 for MP3 tagging if available
  * Bugfix: Crash on cancel
  * Fixes some compile issues with GCC 4.5
  * Some cosmetic fixes
  * English language fix: Uses the word "folder" instead of "directory"
  * Uses KDiskFreeSpaceInfo for calculating free space on a device
  * New feature: Uses mimetype icons for profiles and allows user to change these
  * Settings in profile editing dialog now grouped with tabs
  * Fixes a crash when adding a new profile via the UI
  * New feature: New simple view of the ripping progress dialog
  * Adds more detail to CDDB errors
  * Some small bugfixes... (thx to all reporters!)
- Spec file updates
  - Added a audex-lang package.
  - Changes after spec-cleaner run.
  - Updates in BuildRequires: and %%install sections.
  - Added python-eyeD3 to Recommends: entry.
- Removed the 02_useless_include.diff and audex-0.72b1-compilation_fixes.patch
  patches (fixed upstream).
- Added a patch to make the package use cmake-2.6.4 (fixes build in openSUSE
  11.2).
* Thu Jul 15 2010 bitshuffler@opensuse.org
- Added 02_useless_include.diff
- Added audex-0.72b1-compilation_fixes.patch
* Wed Sep 30 2009 tittiatcoke@gmail.com
- Updated to 0.72b1
  * Cover fetch from google.
  * Minor bugfixes.
* Sun Aug 23 2009 tittiatcoke@gmail.com
- Updated to 0.71b5
  + Updated header information (all GPLv3+ now)
  + Slightly improved czech translation (Pavel Fric)
  + Slightly improved german translation (this is already not perfect!)
  + Minor bugfix.
* Tue Jun 23 2009 tittiatcoke@gmail.com
- Updated to 0.71b3
  + Added translations (Dutch & Portugees)
  + Bugfixes (slider, Update profile loaded from external file)
* Fri May 29 2009 bitshuffler@opensuse.org
- Updated to 0.71b2
* Fri May  8 2009 bitshuffler@opensuse.org
- Updated to 0.70b1
* Sun Mar 29 2009 bitshuffler@opensuse.org
- Updated to 0.62b
* Thu Oct 30 2008 buschmann@huessenbergnetz.de
- fixing file list (directories not owned by a package)
* Mon Apr 14 2008 cgoncalves@opensuse.org
- updated to version 0.6a:
  * New XML-based scheme definitions.
  * Assistant will help you creating profiles.
  * Cover fetching from amazon works again (rewritten).
  * Store SFV files for the music files.
  * Store text files with predefined information.
  * A lot of Bugfixes...
* Mon Mar 17 2008 cgoncalves@opensuse.org
- initial release (version 0.5a)
